from setuptools import setup

setup(name='2022_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['2022_distributions'],
      author = 'Jonathan Koefman',
      author_email = 'jkoefman@outlook.com',
      zip_safe=False)
